@@ -1,11 +1,11 @@
 from ngutils.functions import *
 
-__version__ = '0.9.9'
+__version__ = '0.9.11'
 
 __all__ = [
     'accel_steps',
-    'build_phrase',
     'read_urls_contents',
+    'reduce_content',
     'tune_steps',
     'view_types',
 ]
